@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.66.2.3 2004/05/22 12:43:36 kmaraas Exp $
+ $Id: battstat_applet.c,v 1.74 2004/07/10 11:48:50 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -71,6 +71,8 @@
 #define APMDEVICE "/dev/apm"
 #endif
 
+#define GCONF_PATH ""
+
 GtkObject *statusdock;
 
 static const BonoboUIVerb battstat_menu_verbs [] = {
@@ -347,6 +349,19 @@ apm_readinfo (PanelApplet *applet, ProgressData * battstat)
 
 /* } */
 
+static char *get_remaining (int time)
+{
+	int hours = time / 60;
+	int mins  = time % 60;
+	
+	if (time == -1)
+		return g_strdup_printf(_("charged"));
+	else if (time < 0)
+		return g_strdup_printf(_("..."));
+	else
+		return g_strdup_printf(_("%d hours %d minutes remaining"), hours, mins);	
+}
+	
 gint
 pixmap_timeout( gpointer data )
 {
@@ -361,8 +376,12 @@ pixmap_timeout( gpointer data )
   guint charging;
   gint i, x;
   gboolean batterypresent;
-  gchar new_label[80];
-  gchar new_string[80];
+  gchar *new_label;
+  gchar *new_string;
+  gchar *rem_time = NULL;
+  GtkWidget *hbox, *image, *label, *dialog;
+  GdkPixbuf *pixbuf;
+  
   gchar *status[]={
     /* The following four messages will be displayed as tooltips over
      the battery meter.  
@@ -451,12 +470,39 @@ pixmap_timeout( gpointer data )
      && battery->last_batt_life != 1000
      && battery->last_batt_life > battery->red_val
      && batt_life <= battery->red_val
+     && batterypresent
    ) {
       /* Warn that battery dropped below red_val */
       if(battery->lowbattnotification) {
-         snprintf(new_label, sizeof(new_label),_("Battery low (%d%%) and AC is offline"),
-                  batt_life);
-         battery->lowbattnotificationdialog = gnome_warning_dialog(new_label);
+	 new_string = get_remaining (apminfo.battery_time);
+	 new_label = g_strdup_printf (_("Your battery is running low (%d%%, %s). You should recharge your battery to avoid losing your work."), batt_life, new_string);
+	 g_free (new_string);
+	 battery->lowbattnotificationdialog = gtk_dialog_new_with_buttons (
+			 _("Battery Notice"),
+			 NULL,
+			 GTK_DIALOG_DESTROY_WITH_PARENT,
+			 GTK_STOCK_OK,
+			 GTK_RESPONSE_ACCEPT,
+			 NULL);
+	 g_signal_connect_swapped (GTK_OBJECT (battery->lowbattnotificationdialog), "response",
+			 G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (battery->lowbattnotificationdialog));
+	 gtk_container_set_border_width (GTK_CONTAINER (battery->lowbattnotificationdialog), 6);
+	 gtk_dialog_set_has_separator (GTK_DIALOG (battery->lowbattnotificationdialog), FALSE);
+	 hbox = gtk_hbox_new (FALSE, 6);
+	 pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+			 "gnome-dev-battery",
+			 48,
+			 GTK_ICON_LOOKUP_USE_BUILTIN,
+			 NULL);
+	 image = gtk_image_new_from_pixbuf (pixbuf);
+	 g_object_unref (pixbuf);
+	 gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 6);
+	 label = gtk_label_new (new_label);
+	 gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	 g_free (new_label);
+	 gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 6);
+	 gtk_container_add (GTK_CONTAINER (GTK_DIALOG (battery->lowbattnotificationdialog)->vbox), hbox);
+	 gtk_widget_show_all (battery->lowbattnotificationdialog);
     
          if(battery->beep)
             gdk_beep();
@@ -478,7 +524,32 @@ pixmap_timeout( gpointer data )
       /* Inform that battery now fully charged */
       gnome_triggers_do ("", NULL, "battstat_applet", "BatteryFull", NULL);
       if(battery->fullbattnot) {
-         gnome_ok_dialog( _("Battery is now fully re-charged!"));
+	 dialog = gtk_dialog_new_with_buttons (
+			 _("Battery Notice"),
+			 NULL,
+			 GTK_DIALOG_DESTROY_WITH_PARENT,
+			 GTK_STOCK_OK,
+			 GTK_RESPONSE_ACCEPT,
+			 NULL);
+	 g_signal_connect_swapped (GTK_OBJECT (dialog), "reponse",
+			 G_CALLBACK (gtk_widget_destroy), GTK_OBJECT (dialog));
+	 gtk_container_set_border_width (GTK_CONTAINER (dialog), 6);
+	 gtk_dialog_set_has_separator (GTK_DIALOG (dialog), FALSE);
+	 hbox = gtk_hbox_new (FALSE, 6);
+	 pixbuf = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
+			 "gnome-dev-battery",
+			 48,
+			 GTK_ICON_LOOKUP_USE_BUILTIN,
+			 NULL);
+	 image = gtk_image_new_from_pixbuf (pixbuf);
+	 g_object_unref (pixbuf);
+	 gtk_box_pack_start (GTK_BOX (hbox), image, TRUE, TRUE, 6);
+	 label = gtk_label_new (_("Your battery is now fully recharged."));
+	 gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
+	 gtk_box_pack_start (GTK_BOX (hbox), label, TRUE, TRUE, 6);
+	 gtk_container_add (GTK_CONTAINER (GTK_DIALOG (dialog)->vbox), hbox);
+	 gtk_widget_show_all (dialog);
+	 
          if (battery->beep)
             gdk_beep();
        }
@@ -488,11 +559,21 @@ pixmap_timeout( gpointer data )
        && charging
        && acline_status
        && batterypresent
-       && battery->lowbattnotificationdialog
       ) {
-	   /* we can remove the battery warning dialog */
-	   gtk_widget_destroy (battery->lowbattnotificationdialog);
-	   battery->lowbattnotificationdialog = NULL;
+	   /*
+	    * the battery is charging again, reset the dialog display flag
+	    * Thanks to Richard Kinder <r_kinder@yahoo.com> for this patch.
+	    */
+	   battery->lowbattnotification = panel_applet_gconf_get_bool (
+			   PANEL_APPLET(battery->applet),
+			   GCONF_PATH "low_battery_notification", NULL);
+
+	   if (battery->lowbattnotificationdialog)
+	   {
+		   /* we can remove the battery warning dialog */
+		   gtk_widget_destroy (battery->lowbattnotificationdialog);
+		   battery->lowbattnotificationdialog = NULL;
+	   }
    }
 
    if(
@@ -507,21 +588,17 @@ pixmap_timeout( gpointer data )
 
       if(!battery->showbattery && !battery->showpercent) {
 	 if(acline_status == 0) {
-	    snprintf(new_label, sizeof(new_label),
-		     _("System is running on battery power\nBattery: %d%% (%s)"),
+		new_label = g_strdup_printf (_("System is running on battery power\nBattery: %d%% (%s)"),
 		     batt_life, _(status[batt_state]));
 	 } else {
-	    snprintf(new_label, sizeof(new_label),
-		     _("System is running on AC power\nBattery: %d%% (%s)"),
+		new_label = g_strdup_printf (_("System is running on AC power\nBattery: %d%% (%s)"),
 		     batt_life, _(status[batt_state]));
 	 }
       } else {
 	 if(acline_status == 0) {
-	    snprintf(new_label, sizeof(new_label),
-		     _("System is running on battery power"));
+		new_label = g_strdup (_("System is running on battery power"));
 	 } else {
-	    snprintf(new_label, sizeof(new_label),
-		     _("System is running on AC power"));
+		new_label = g_strdup (_("System is running on AC power"));
 	 }
       }
 
@@ -529,17 +606,19 @@ pixmap_timeout( gpointer data )
 			    battery->eventstatus,
 			    new_label,
 			    NULL);
+      g_free (new_label);
    
       /* Update the battery meter, tooltip and label */
       
       if (batterypresent) {
-	 snprintf(new_label, sizeof(new_label),"%d%%", batt_life);
+	 new_label = g_strdup_printf ("%d%%", batt_life);
       } else {
-	 snprintf(new_label, sizeof(new_label),_("N/A"));
+	 new_label = g_strdup (_("N/A"));
       }
 
       gtk_label_set_text (GTK_LABEL (battery->percent), new_label);
       gtk_label_set_text (GTK_LABEL (battery->statuspercent), new_label);
+      g_free (new_label);
       
       if (batt_life <= battery->red_val) {
 	 color=red;
@@ -653,56 +732,54 @@ pixmap_timeout( gpointer data )
 	 }
       }
       
+      if (batt_state != 3)
+	      rem_time = get_remaining(apminfo.battery_time);
+      else
+	      rem_time = g_strdup(_(status[batt_state]));
+      
       if (battery->showstatus == 0) {
 	 if (batterypresent) {
 	    if(acline_status == 0) {
-	       snprintf(new_string, sizeof(new_string), 
 			/* This string will display as a tooltip over the battery frame
 			 when the computer is using battery power.*/
-			_("System is running on battery power. Battery: %d%% (%s)"),
-			batt_life,
-			_(status[batt_state]));
+		new_string = g_strdup_printf (_("System is running on battery power. Battery: %d%% (%s)"),
+			batt_life, rem_time);
 	    } else {
-	       snprintf(new_string, sizeof(new_string), 
 			/* This string will display as a tooltip over the battery frame
 			 when the computer is using AC power.*/
-			_("System is running on AC power. Battery: %d%% (%s)"),
-			batt_life,
-			_(status[batt_state]));
+		new_string = g_strdup_printf (_("System is running on AC power. Battery: %d%% (%s)"),
+			batt_life, rem_time);
 	    }
 	 } else {
 	    if(acline_status == 0) {
-	       snprintf(new_string, sizeof(new_string), 
 			/* This string will display as a tooltip over the
 			 battery frame when the computer is using battery
 			 power and the battery isn't present. Not a
 			 possible combination, I guess... :)*/
-			_("System is running on battery power. Battery: Not present"));
+		new_string = g_strdup (_("System is running on battery power. Battery: Not present"));
 	    } else {
-	       snprintf(new_string, sizeof(new_string), 
 			/* This string will display as a tooltip over the
 			 battery frame when the computer is using AC
 			 power and the battery isn't present.*/
-			_("System is running on AC power. Battery: Not present"));
+		new_string = g_strdup (_("System is running on AC power. Battery: Not present"));
 	    }
 	 }
       } else {
 	 if (batterypresent) {
-	   snprintf(new_string, sizeof(new_string), 
 		    /* Displayed as a tooltip over the battery meter when there is
 		     a battery present. %d will hold the current charge and %s will
-		     hold the status of the battery, (High, Low, Critical, Charging. */
-		    (_("Battery: %d%% (%s)")),
-		    batt_life,
-		    _(status[batt_state]));
+		     contains a string of the time remaining */
+		new_string = g_strdup_printf ((_("Battery: %d%% (%s)")),
+		    batt_life, rem_time);
 	 } else {
-	    snprintf(new_string, sizeof(new_string), 
 		     /* Displayed as a tooltip over the battery meter when no
 		      battery is present. */
-		     (_("Battery: Not present")));
+		new_string = g_strdup (_("Battery: Not present"));
 	 }
       }
       
+      g_free (rem_time);
+      
       gtk_tooltips_set_tip(battery->progress_tip,
 			   battery->eventbattery,
 			   gettext(new_string),
@@ -711,6 +788,7 @@ pixmap_timeout( gpointer data )
 			   battery->eventybattery,
 			   gettext(new_string),
 			   NULL);
+      g_free (new_string);
       
       if (DEBUG) printf("Percent: %d, Status: %s\n", batt_life, status[batt_state]);
    }
@@ -956,7 +1034,7 @@ change_orient (PanelApplet       *applet,
 	       PanelAppletOrient  orient,
 	       ProgressData      *battstat)
 {
-   gchar new_label[80];
+   gchar *new_label;
    guint acline_status;
    guint batt_state;
    guint batt_life;
@@ -999,11 +1077,6 @@ change_orient (PanelApplet       *applet,
 
    switch(battstat->orienttype) {
     case PANEL_APPLET_ORIENT_UP:
-      if(battstat->panelsize<40)
-	battstat->horizont=TRUE;
-      else
-	battstat->horizont=FALSE;
-      break;
     case PANEL_APPLET_ORIENT_DOWN:
       if(battstat->panelsize<40)
 	battstat->horizont=TRUE;
@@ -1011,10 +1084,11 @@ change_orient (PanelApplet       *applet,
 	battstat->horizont=FALSE;
       break;
     case PANEL_APPLET_ORIENT_LEFT:
-      battstat->horizont=FALSE;
-      break;
     case PANEL_APPLET_ORIENT_RIGHT:
-      battstat->horizont=FALSE;
+      if (battstat->panelsize>=60)
+	battstat->horizont=TRUE;
+      else
+	battstat->horizont=FALSE;
       break;
    }
    
@@ -1036,42 +1110,40 @@ change_orient (PanelApplet       *applet,
       
       if (battstat->showbattery == 0 && battstat->showpercent == 0) {
 	 if(acline_status == 0) {
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power and the battery meter
 		      and percent meter is hidden by the user.*/
-		     _("System is running on battery power. Battery: %d%% (%s)"),
+		new_label = g_strdup_printf (_("System is running on battery power. Battery: %d%% (%s)"),
 		     batt_life, _(status[batt_state]));
 	 } else {
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power and the battery meter
 		      and percent meter is hidden by the user.*/
-		     _("System is running on AC power. Battery: %d%% (%s)"),
+		new_label = g_strdup_printf (_("System is running on AC power. Battery: %d%% (%s)"),
 		     batt_life, _(status[batt_state]));      
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
 			       new_label,
 			       NULL);
+	 g_free (new_label);
       } else {
 	 if(acline_status == 0) {
 	    /* 0 = Battery power */
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power.*/
-		     _("System is running on battery power"));
+		new_label = g_strdup (_("System is running on battery power"));
 	 } else {
 	    /* 1 = AC power. I should really test it explicitly here. */
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power.*/
-		     _("System is running on AC power"));
+		new_label = g_strdup(_("System is running on AC power"));
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
 			       new_label,
 			       NULL);
+	 g_free (new_label);
 #ifdef FIXME
 	 gtk_widget_set_usize(battstat->framestatus, 20, 24);
 	 if(battstat->showbattery == 1 && battstat->showpercent == 1) {
@@ -1124,43 +1196,41 @@ change_orient (PanelApplet       *applet,
       if(battstat->showbattery == 0 && battstat->showpercent == 0) {
 	 if(acline_status == 0) {
 	    /* 0 = Battery power */
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power and the battery meter
 		      and percent meter is hidden by the user.*/
-		     _("System is running on battery power\nBattery: %d%% (%s)"),
+		new_label = g_strdup_printf (_("System is running on battery power\nBattery: %d%% (%s)"),
 		     batt_life, _(status[batt_state]));
 	 } else {
 	    /* 1 = AC power. I should really test it explicitly here. */
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power and the battery meter
 		      and percent meter is hidden by the user.*/
-		     _("System is running on AC power\nBattery: %d%% (%s)"),
+		new_label = g_strdup_printf (_("System is running on AC power\nBattery: %d%% (%s)"),
 		     batt_life, _(status[batt_state]));
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
 			       new_label,
 			       NULL);
+	 g_free (new_label);
       } else {
 	 if(acline_status == 0) {
 	    /* 0 = Battery power */
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using battery power.*/
-		     _("System is running on battery power"));
+		new_label = g_strdup (_("System is running on battery power"));
 	 } else {
 	    /* 1 = AC power. I should really test it explicitly here. */
-	    snprintf(new_label, sizeof(new_label),
 		     /* This string will display as a tooltip over the status frame
 		      when the computer is using AC power.*/
-		     _("System is running on AC power"));
+		new_label = g_strdup (_("System is running on AC power"));
 	 }
 	 gtk_tooltips_set_tip (battstat->ac_tip,
 			       battstat->eventstatus,
 			       new_label,
 			       NULL);
+	 g_free (new_label);
       }
    }
    
@@ -1171,7 +1241,7 @@ void
 simul_cb (GtkWidget *ignored, gpointer data)
 {
    ProgressData *battery = data;
-   gchar new_label[40];
+   gchar *new_label;
    GdkColor *color, *darkcolor;
    gint slidervalue;
    gint prefred, preforange, prefyellow, progress_value, i, x;
@@ -1181,11 +1251,11 @@ simul_cb (GtkWidget *ignored, gpointer data)
    preforange =(int) GTK_ADJUSTMENT (battery->eorange_adj)->value;
    prefred =(int) GTK_ADJUSTMENT (battery->ered_adj)->value;
    
-   snprintf(new_label,
-	    sizeof(new_label),
+   new_label = g_strdup_printf (
 	    "%d%%",
 	    slidervalue);
    gtk_label_set_text ( GTK_LABEL (battery->testpercent), new_label);
+   g_free (new_label);
    
    if (slidervalue <= prefred) {
       color=red;
@@ -1349,9 +1419,6 @@ key_press_cb (GtkWidget *widget, GdkEventKey *event, ProgressData *battstat)
 	return FALSE;
 }
 
-
-#define GCONF_PATH ""
-
 void
 load_preferences(ProgressData *battstat)
 {
