@@ -41,6 +41,8 @@
 
 #define STOCK_QUOTE(sq) ((StockQuote *)(sq))
 
+#define MAX_SYMBOL_LEN 1024
+
 #define NEVER_SENSITIVE		"never_sensitive"
 
 	enum {
@@ -274,8 +276,10 @@ static gint updateOutput(gpointer data)
 		stockdata->vfshandle = NULL;
 	}
 
-	if (stockdata->props.tik_syms == NULL)
+	if (stockdata->props.tik_syms == NULL) {
+		setOutputArray (stockdata, _("No stock list"));
 		return TRUE;
+	}
         /*
          * Now using a CSV file to get quotes. Specification of CSV format
          * is in URL f=sl1c1.
@@ -427,7 +431,7 @@ static gint updateOutput(gpointer data)
 
 
 	/*-----------------------------------------------------------------*/
-	static char *parseQuote(char line[1024]) {
+	static char *parseQuote(char line[MAX_SYMBOL_LEN]) {
 		
                 char *symbol;
                 char *price;
@@ -476,7 +480,7 @@ static gint updateOutput(gpointer data)
 	int configured(StockData *stockdata) {
 		int retVar;
 
-		char  buffer[1024];
+		char  buffer[MAX_SYMBOL_LEN];
 		static FILE *CONFIG;
 
 		CONFIG = fopen((const char *)stockdata->configFileName,"r");
@@ -971,24 +975,49 @@ static gint updateOutput(gpointer data)
 		GtkTreeModel *model;
 		GtkTreeIter row;
 		gchar *symbol;
+		gchar *temp_symbol;
+		gchar *full_symbol;
 		gchar *tmp;
+		gint symbol_len;
+		gint i, j=0;
+		gboolean flag = FALSE;
 		
 		symbol = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
+		symbol_len = strlen (symbol);
+
+		full_symbol = (char *) malloc ((symbol_len + 1) * sizeof (char));
 		if (!symbol)
 			return;
-		
-		g_strstrip (symbol);
-		
+
 		if (strlen (symbol) < 1) {
 			g_free (symbol);
 			return;
 		}
 		
+		for (i=0; i<symbol_len; i++) {
+			if (symbol[i] == ' ' || symbol[i] == ',') {
+				if (flag) {
+					full_symbol[j]='+';
+					j++;
+					flag = FALSE;
+				}
+				else 
+					continue;
+			}
+			else {
+				full_symbol[j] = symbol[i];
+				j++;
+				flag = TRUE;
+			}
+		}
+
+		full_symbol[j]= '\0';
+		
 		tmp = stockdata->props.tik_syms;
 		if (tmp)
-			stockdata->props.tik_syms = g_strconcat (tmp, "+", symbol, NULL);
+			stockdata->props.tik_syms = g_strconcat (tmp, "+", full_symbol, NULL);
 		else
-			stockdata->props.tik_syms = g_strdup (symbol);
+			stockdata->props.tik_syms = g_strdup (full_symbol);
 		
 		panel_applet_gconf_set_string (applet, "tik_syms", 
 					       stockdata->props.tik_syms, NULL);
@@ -998,12 +1027,18 @@ static gint updateOutput(gpointer data)
 		
 		list = g_object_get_data (G_OBJECT (entry), "list");
 		model = gtk_tree_view_get_model (GTK_TREE_VIEW (list));
-		gtk_list_store_append (GTK_LIST_STORE (model), &row);
-		gtk_list_store_set (GTK_LIST_STORE (model), &row, 
-					    0, symbol, -1);
+
+		temp_symbol = strtok (full_symbol, "+");
+		for (; temp_symbol;) {
+			gtk_list_store_append (GTK_LIST_STORE (model), &row);
+			gtk_list_store_set (GTK_LIST_STORE (model), &row, 
+					    0, temp_symbol, -1);
+			temp_symbol = strtok (NULL, "+");
+		}
 					    
 		gtk_entry_set_text (entry, "");
 		g_free (symbol);
+		g_free (full_symbol);
 		updateOutput(stockdata);
 		
 	}
@@ -1219,6 +1254,7 @@ static gint updateOutput(gpointer data)
 		stockdata->tik_syms_entry = list;
 		
 		swindow = gtk_scrolled_window_new(NULL,NULL);
+		gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (swindow), GTK_SHADOW_IN);
 		gtk_scrolled_window_set_policy(GTK_SCROLLED_WINDOW(swindow),
 						GTK_POLICY_AUTOMATIC,
 						GTK_POLICY_AUTOMATIC);
@@ -1935,8 +1971,8 @@ static gint updateOutput(gpointer data)
 
 	/*-----------------------------------------------------------------*/
 	char *splitPrice(char *data) {
-		char buff[128]="";
-		static char buff2[128]="";
+		char buff[MAX_SYMBOL_LEN]="";
+		static char buff2[MAX_SYMBOL_LEN]="";
 		char *var1, *var2;
 
 		strcpy(buff,data);
@@ -1953,13 +1989,13 @@ static gint updateOutput(gpointer data)
 
 	/*-----------------------------------------------------------------*/
 	char *splitChange(StockData *stockdata,char *data, StockQuote *quote) {
-		char buff[128]; 
-		static char buff2[128];
+		char buff[MAX_SYMBOL_LEN]; 
+		static char buff2[MAX_SYMBOL_LEN];
 		char *var1, *var2, *var3, *var4;
 		char rise[2]; 
 
-                bzero(buff, 128); 
-                bzero(buff2, 128); 
+                bzero(buff, MAX_SYMBOL_LEN); 
+                bzero(buff2, MAX_SYMBOL_LEN); 
                 bzero(rise, 2); 
                 
 		strcpy(buff,data);
@@ -1989,8 +2025,8 @@ static gint updateOutput(gpointer data)
 			quote->color = RED;
 		}
 		else {
-			var3 = g_strdup(_("(No"));
-			var4 = g_strdup(_("Change "));
+			var3 = g_strdup(_("(No Change"));
+			var4 = g_strdup("");
 			quote->color = WHITE;
 		}
 
