@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.78.2.1 2004/06/08 12:07:09 kmaraas Exp $ */
+/* $Id: gweather-applet.c,v 1.85 2004/07/07 00:52:12 gowen Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -32,16 +32,22 @@
 
 static void place_widgets (GWeatherApplet *gw_applet)
 {
-    PangoLayout *panlay;
-    int size = gw_applet->size;
+    GtkRequisition req;
+    int total_size = 0;
+    gboolean horizontal = FALSE;
+    int panel_size = gw_applet->size;
     const gchar *temp;   
-    int textheight, textwidth;
-    int picheight = 0, picwidth = 0;
-
-    if (gw_applet->box)
-	gtk_widget_destroy (gw_applet->box);
-    
-    gw_applet->label = gtk_label_new("0\302\260F");
+	
+    switch (gw_applet->orient) {
+	case PANEL_APPLET_ORIENT_LEFT:
+	case PANEL_APPLET_ORIENT_RIGHT:
+	    horizontal = FALSE;
+	    break;
+	case PANEL_APPLET_ORIENT_UP:
+	case PANEL_APPLET_ORIENT_DOWN:
+	    horizontal = TRUE;
+	    break;
+    }
 
     /* Create the weather icon */
     weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
@@ -50,47 +56,47 @@ static void place_widgets (GWeatherApplet *gw_applet)
     gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
     			       gw_applet->applet_pixbuf);
 
-    /* We check against the weather indication icon sizes for box reordering */
+    /* Check the weather icon sizes to determine box layout */
     if (gw_applet->applet_pixbuf != NULL) {
-	picwidth = gdk_pixbuf_get_width(gw_applet->applet_pixbuf);
-	picheight = gdk_pixbuf_get_height(gw_applet->applet_pixbuf);
-    }
-    
-    /* We check against text sizes for box reordering */
-    panlay = gtk_label_get_layout(GTK_LABEL (gw_applet->label));
-    pango_layout_get_pixel_size(panlay, &textwidth, &textheight);
-
-    /* Set the right box for the dimension and panel type */
-    if (gw_applet->orient == PANEL_APPLET_ORIENT_UP || gw_applet->orient == PANEL_APPLET_ORIENT_DOWN) {
-	size = gw_applet->container->allocation.height;
-
-	if (size < picheight + textheight + 9)
-		gw_applet->box = gtk_hbox_new (FALSE, 2);
-	else
-		gw_applet->box = gtk_vbox_new (FALSE, 2);
-	
-    } else if (gw_applet->orient == PANEL_APPLET_ORIENT_RIGHT || gw_applet->orient == PANEL_APPLET_ORIENT_LEFT) {
-	size = gw_applet->container->allocation.width;
-
-	if (size > picwidth + textwidth + 18)
-		gw_applet->box = gtk_hbox_new (FALSE, 2);
-	else
-		gw_applet->box = gtk_vbox_new (FALSE, 2);
-    
-    } else {
-	gw_applet->box = gtk_vbox_new (FALSE, 2);
+        gtk_widget_size_request(gw_applet->image, &req);
+        if (horizontal)
+            total_size += req.height;
+        else
+            total_size += req.width;
     }
 
-    /* Rebuild the applet it's visual area */
-    gtk_container_add (GTK_CONTAINER (gw_applet->container), gw_applet->box);
-
-    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->image, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->label, FALSE, FALSE, 0);
-
+    /* Create the temperature label */
+    gw_applet->label = gtk_label_new("0\302\260F");
+    
     /* Update temperature text */
     temp = weather_info_get_temp_summary(gw_applet->gweather_info);
     if (temp) 
-    	gtk_label_set_text(GTK_LABEL(gw_applet->label), temp);
+        gtk_label_set_text(GTK_LABEL(gw_applet->label), temp);
+
+    /* Check the label size to determine box layout */
+    gtk_widget_size_request(gw_applet->label, &req);
+    if (horizontal)
+        total_size += req.height;
+    else
+        total_size += req.width;
+
+    /* Pack the box */
+    if (gw_applet->box)
+        gtk_widget_destroy (gw_applet->box);
+    
+    if (horizontal && (total_size <= panel_size))
+        gw_applet->box = gtk_vbox_new(FALSE, 0);
+    else if (horizontal && (total_size > panel_size))
+        gw_applet->box = gtk_hbox_new(FALSE, 2);
+    else if (!horizontal && (total_size <= panel_size))
+        gw_applet->box = gtk_hbox_new(FALSE, 2);
+    else 
+        gw_applet->box = gtk_vbox_new(FALSE, 0);
+
+    /* Rebuild the applet it's visual area */
+    gtk_container_add (GTK_CONTAINER (gw_applet->container), gw_applet->box);
+    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->image, TRUE, TRUE, 0);
+    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->label, TRUE, TRUE, 0);
 
     gtk_widget_show_all (GTK_WIDGET (gw_applet->applet));
 }
@@ -104,11 +110,20 @@ static void change_orient_cb (PanelApplet *w, PanelAppletOrient o, gpointer data
     return;
 }
 
-static void change_size_cb(PanelApplet *w, gint s, gpointer data)
+static void size_allocate_cb(PanelApplet *w, GtkAllocation *allocation, gpointer data)
 {
     GWeatherApplet *gw_applet = (GWeatherApplet *)data;
 	
-    gw_applet->size = s;
+    if ((gw_applet->orient == PANEL_APPLET_ORIENT_LEFT) || (gw_applet->orient == PANEL_APPLET_ORIENT_RIGHT)) {
+      if (gw_applet->size == allocation->width)
+	return;
+      gw_applet->size = allocation->width;
+    } else {
+      if (gw_applet->size == allocation->height)
+	return;
+      gw_applet->size = allocation->height;
+    }
+	
     place_widgets(gw_applet);
     return;
 }
@@ -147,9 +162,11 @@ static void change_background_cb (
 static gboolean clicked_cb (GtkWidget *widget, GdkEventButton *ev, gpointer data)
 {
     GWeatherApplet *gw_applet = data;
+
     if ((ev == NULL) || (ev->button != 1))
-	    return FALSE;
-    if (ev->type == GDK_2BUTTON_PRESS) {
+        return FALSE;
+
+    if (ev->type == GDK_BUTTON_PRESS) {
 	gweather_dialog_open(gw_applet);
 	return TRUE;
     }
@@ -297,15 +314,19 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
     GtkWidget *pixmap;
     GtkTooltips *tooltips;
     GtkIconInfo *icon_info;
+    AtkObject *atk_obj;
 
     gw_applet->about_dialog = NULL;
  
     gw_applet->gweather_pref.location = NULL;
     gw_applet->gweather_pref.update_interval = 1800;
     gw_applet->gweather_pref.update_enabled = TRUE;
-    gw_applet->gweather_pref.use_metric = FALSE;
     gw_applet->gweather_pref.detailed = FALSE;
     gw_applet->gweather_pref.radar_enabled = TRUE;
+	gw_applet->gweather_pref.temperature_unit = TEMP_UNIT_INVALID;
+	gw_applet->gweather_pref.speed_unit = SPEED_UNIT_INVALID;
+	gw_applet->gweather_pref.pressure_unit = PRESSURE_UNIT_INVALID;
+	gw_applet->gweather_pref.distance_unit = DISTANCE_UNIT_INVALID;
     
     panel_applet_set_flags (gw_applet->applet, PANEL_APPLET_EXPAND_MINOR);
     
@@ -315,13 +336,13 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
         gtk_icon_info_free (icon_info);
     }
 
-    gw_applet->container = gtk_alignment_new(0.5, 0.5, 0, 0);
+    gw_applet->container = gtk_alignment_new (0.5, 0.5, 0, 0);
     gtk_container_add (GTK_CONTAINER (gw_applet->applet), gw_applet->container);
 
     g_signal_connect (G_OBJECT(gw_applet->applet), "change_orient",
                        G_CALLBACK(change_orient_cb), gw_applet);
-    g_signal_connect (G_OBJECT(gw_applet->applet), "change_size",
-                       G_CALLBACK(change_size_cb), gw_applet);
+    g_signal_connect (G_OBJECT(gw_applet->applet), "size_allocate",
+                       G_CALLBACK(size_allocate_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "change_background",
 		       G_CALLBACK(change_background_cb), gw_applet);
     g_signal_connect (G_OBJECT(gw_applet->applet), "destroy", 
@@ -335,6 +356,10 @@ void gweather_applet_create (GWeatherApplet *gw_applet)
 
     gtk_tooltips_set_tip(tooltips, GTK_WIDGET(gw_applet->applet), _("GNOME Weather"), NULL);
 
+    atk_obj = gtk_widget_get_accessible (GTK_WIDGET (gw_applet->applet));
+    if (GTK_IS_ACCESSIBLE (atk_obj))
+	   atk_object_set_name (atk_obj, _("GNOME Weather"));
+
     gw_applet->size = panel_applet_get_size (gw_applet->applet);
 
     gw_applet->orient = panel_applet_get_orient (gw_applet->applet);
@@ -414,14 +439,10 @@ void update_finish (WeatherInfo *info)
     char *s;
     GWeatherApplet *gw_applet = info->applet;
    
-    gw_applet->gweather_info = info;
     weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
     				 &(gw_applet->applet_pixbuf));
     gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
     			       gw_applet->applet_pixbuf);
-
-    if (gw_applet->gweather_pref.use_metric)
-        weather_info_to_metric (gw_applet->gweather_info);
       
     gtk_label_set_text(GTK_LABEL(gw_applet->label), 
 			weather_info_get_temp_summary(gw_applet->gweather_info));
