@@ -1,4 +1,4 @@
-/* $Id: gweather-pref.c,v 1.72 2004/02/01 17:14:14 kevinv Exp $ */
+/* $Id: gweather-pref.c,v 1.79 2004/06/20 20:56:14 dsmit Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -21,6 +21,8 @@
 #include <stdlib.h>
 #include <assert.h>
 #include <ctype.h>
+#include <langinfo.h>
+#include <locale.h>
 
 #include <gnome.h>
 #include <panel-applet.h>
@@ -28,20 +30,65 @@
 #include <gconf/gconf-client.h>
 #include <egg-screen-help.h>
 
+#include <libxml/parser.h>
+#include <libxml/tree.h>
+
 #include "gweather.h"
 #include "gweather-pref.h"
 #include "gweather-applet.h"
+#include "gweather-xml.h"
 
 #define NEVER_SENSITIVE		"never_sensitive"
 
+
+/* gconf keys */
+#define GCONF_TEMP_UNIT     "temperature_unit"
+#define GCONF_SPEED_UNIT    "speed_unit"
+#define GCONF_PRESSURE_UNIT "pressure_unit"
+#define GCONF_DISTANCE_UNIT "distance_unit"
+
 enum
 {
     COL_LOC = 0,
     COL_POINTER,
-    NUM_COLUMNS,
+    NUM_COLUMNS
 }; 
 
 
+static GConfEnumStringPair temp_unit_enum_map [] = {
+    { TEMP_UNIT_DEFAULT,    "Default" },
+    { TEMP_UNIT_KELVIN,     "K"       },
+    { TEMP_UNIT_CENTIGRADE, "C"       },
+    { TEMP_UNIT_FAHRENHEIT, "F"       },
+    { 0, NULL }
+};	
+
+static GConfEnumStringPair speed_unit_enum_map [] = {
+    { SPEED_UNIT_DEFAULT, "Default" },
+    { SPEED_UNIT_MS,      "m/s"     },
+    { SPEED_UNIT_KPH,     "km/h"    },
+    { SPEED_UNIT_MPH,     "mph"     },
+    { SPEED_UNIT_KNOTS,   "knots"   },
+	{ 0, NULL }
+};
+
+static GConfEnumStringPair pressure_unit_enum_map [] = {
+    { PRESSURE_UNIT_DEFAULT, "Default" },
+	{ PRESSURE_UNIT_HPA,     "hPa"     },
+	{ PRESSURE_UNIT_MB,      "mb"      },
+    { PRESSURE_UNIT_MM_HG,   "mmHg"    },
+	{ PRESSURE_UNIT_INCH_HG, "inHg"    },
+    { 0, NULL }
+};
+
+static GConfEnumStringPair distance_unit_enum_map [] = {
+    { DISTANCE_UNIT_DEFAULT, "Default" },
+    { DISTANCE_UNIT_METERS,  "m"       },
+    { DISTANCE_UNIT_KM,      "km"      },
+    { DISTANCE_UNIT_MILES,   "mi"      },
+    { 0, NULL }
+};
+
 static void gweather_pref_set_accessibility (GWeatherApplet *gw_applet);
 static void help_cb (GtkDialog *dialog);
 
@@ -93,11 +140,6 @@ add_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType type)
     AtkRelationSet *relation_set;
     AtkRelation *relation;
    
-    /* If the relation is LABELLED_BY set LABEL_FOR also */
-
-    if (type == ATK_RELATION_LABELLED_BY)
-       gtk_label_set_mnemonic_widget (GTK_LABEL (widget2), widget1);
-
     atk_obj1 = gtk_widget_get_accessible (widget1);
     if (! GTK_IS_ACCESSIBLE (atk_obj1))
        return;
@@ -171,8 +213,34 @@ static gboolean update_dialog (GWeatherApplet *gw_applet)
     				 gw_applet->gweather_pref.update_enabled);
     soft_set_sensitive(gw_applet->pref_basic_update_spin, 
     			     gw_applet->gweather_pref.update_enabled);
-    gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_metric_btn), 
-    				 gw_applet->gweather_pref.use_metric);
+
+    if ( gw_applet->gweather_pref.use_temperature_default) {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_temp_combo), 0);
+    } else {
+		gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_temp_combo), 
+	                 gw_applet->gweather_pref.temperature_unit -1);
+    }
+	
+    if ( gw_applet->gweather_pref.use_speed_default) {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_speed_combo), 0);
+    } else {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_speed_combo), 
+	                 gw_applet->gweather_pref.speed_unit -1);
+    }
+	
+    if ( gw_applet->gweather_pref.use_pressure_default) {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_pres_combo), 0);
+    } else {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_pres_combo), 
+	                 gw_applet->gweather_pref.pressure_unit -1);
+    }
+    if ( gw_applet->gweather_pref.use_distance_default) {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_dist_combo), 0);
+    } else {
+        gtk_combo_box_set_active (GTK_COMBO_BOX(gw_applet->pref_basic_dist_combo), 
+	                 gw_applet->gweather_pref.distance_unit -1);
+    }
+
 #if 0
     gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(gw_applet->pref_basic_detailed_btn), 
     				 gw_applet->gweather_pref.detailed);
@@ -253,128 +321,39 @@ static void row_selected_cb (GtkTreeSelection *selection, gpointer data)
     if (!gtk_tree_selection_get_selected (selection, &model, &iter))
     	return;
     	
-    gtk_tree_model_get (model, &iter, COL_POINTER, &loc, -1);
+    gtk_tree_model_get (model, &iter, GWEATHER_PREF_COL_POINTER, &loc, -1);
     
     if (!loc)
     	return;
 
-    panel_applet_gconf_set_string(gw_applet->applet, "location0", loc->name, NULL);
+    panel_applet_gconf_set_string(gw_applet->applet, "location0", loc->untrans_name, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "location1", loc->code, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "location2", loc->zone, NULL);
     panel_applet_gconf_set_string(gw_applet->applet, "location3", loc->radar, NULL);
+    panel_applet_gconf_set_string(gw_applet->applet, "location4", loc->trans_name, NULL);
     if (gw_applet->gweather_pref.location) {
        weather_location_free (gw_applet->gweather_pref.location);
     }
+    
     gw_applet->gweather_pref.location = weather_location_config_read (gw_applet->applet);
     gweather_update (gw_applet);
 } 
 
-static void load_region (GWeatherApplet *gw_applet, GtkTreeIter *parent_iter, const gchar *region_key)
-{
-    GtkTreeView *tree;
-    GtkTreeStore *model;
-    GtkTreeIter region_iter;
-    gchar *subregions_key;
-    gint isubregions, nsubregions;
-    gchar **subregions;
-    gchar *name_key;
-    gchar *name;
-    void *iter;
-    gchar *iter_key, *iter_val;
-    
-    tree = GTK_TREE_VIEW (gw_applet->pref_tree);
-    model = GTK_TREE_STORE (gtk_tree_view_get_model (tree));
-    
-    name_key = g_strconcat (region_key, "/name", NULL);
-    name = gnome_config_get_string (name_key);
-    
-    gtk_tree_store_insert (model, &region_iter, parent_iter, 0);
-    gtk_tree_store_set (model, &region_iter, COL_LOC, name, -1);
-    
-    subregions_key = g_strconcat (region_key, "/regions", NULL);
-    gnome_config_get_vector (subregions_key, &nsubregions, &subregions);
-    
-    for (isubregions = nsubregions-1;  isubregions >= 0;  isubregions--) {
-        gchar *subregion_key = g_strconcat (region_key, "_", subregions[isubregions], NULL);
-        
-        load_region (gw_applet, &region_iter, subregion_key);
-        
-        g_free (subregion_key);
-    }
-    
-    iter = gnome_config_init_iterator (region_key);
-    while ((iter = gnome_config_iterator_next (iter, &iter_key, &iter_val)) != NULL) {
-        if (strstr (iter_key, "loc") != NULL) {
-            GtkTreeIter loc_iter;
-            gchar **locdata;
-            gint nlocdata;
-            WeatherLocation *weather_location;
-            
-            gnome_config_make_vector (iter_val, &nlocdata, &locdata);
-            g_return_if_fail (nlocdata == 4);
-            
-            weather_location = weather_location_new (locdata[0], 
-                                                     locdata[1], 
-                                                     locdata[2], 
-                                                     locdata[3]);
-            gtk_tree_store_insert (model, &loc_iter, &region_iter, 0);
-            gtk_tree_store_set (model, &loc_iter, COL_LOC, locdata[0], 
-        			COL_POINTER, weather_location, -1);
-            
-            if (gw_applet->gweather_pref.location && weather_location_equal (weather_location, gw_applet->gweather_pref.location)) {
-                GtkTreePath *path;
-                path = gtk_tree_model_get_path (GTK_TREE_MODEL (model), 
-                                                &loc_iter);
-                gtk_tree_view_expand_to_path (tree, path);
-                gtk_tree_view_set_cursor (tree, path, NULL, FALSE);
-                gtk_tree_view_scroll_to_cell (tree, path, NULL, TRUE, 0.5, 0.5);
-                gtk_tree_path_free (path);
-            }
-            
-            g_strfreev (locdata);
-        }
-        
-        g_free(iter_key);
-        g_free(iter_val);
-    }
-    
-    g_free (name);
-    g_free (name_key);
-    g_free (subregions_key);
-    g_strfreev (subregions);
-}
-
 static void load_locations (GWeatherApplet *gw_applet)
 {
     GtkTreeView *tree = GTK_TREE_VIEW(gw_applet->pref_tree);
     GtkTreeViewColumn *column;
-    GtkCellRenderer *cell_renderer;
-    gint iregions, nregions;
-    gchar **regions;
-    gchar *pp[1], *path;
-    gchar *file;
-    
-    file = gnome_datadir_file("gweather/Locations");
-    g_return_if_fail (file);
-    path = g_strdup_printf("=%s=/", file);
-    gnome_config_push_prefix(path);
-    g_free(path);
-    g_free (file);
-    
+    GtkCellRenderer *cell_renderer;	
+        
+    /* Add a colum for the locations */
     cell_renderer = gtk_cell_renderer_text_new ();
     column = gtk_tree_view_column_new_with_attributes ("not used", cell_renderer,
-						       "text", COL_LOC, NULL);
+						       "text", GWEATHER_PREF_COL_LOC, NULL);
     gtk_tree_view_append_column (tree, column);
     gtk_tree_view_set_expander_column (GTK_TREE_VIEW (tree), column);
     
-    gnome_config_get_vector ("Main/regions", &nregions, &regions);
-
-    for (iregions = nregions-1;  iregions >= 0;  iregions--) {
-        load_region (gw_applet, NULL, regions[iregions]);
-    }
-    
-    g_strfreev (regions);
-    gnome_config_pop_prefix();
+    /* load locations from xml file */
+    gweather_xml_load_locations(tree, gw_applet->gweather_pref.location);
 }
 
 static void
@@ -395,33 +374,6 @@ auto_update_toggled (GtkToggleButton *button, gpointer data)
                                  timeout_cb, gw_applet);
 }
 
-static void
-metric_toggled (GtkToggleButton *button, gpointer data)
-{
-    GWeatherApplet *gw_applet = data;
-    gboolean toggled;
-    
-    toggled = gtk_toggle_button_get_active(button);
-    if (gw_applet->gweather_pref.use_metric == toggled)
-        return;
-        
-    gw_applet->gweather_pref.use_metric = toggled;
-    panel_applet_gconf_set_bool(gw_applet->applet, "enable_metric", toggled, NULL);
-    
-    if (!gw_applet->gweather_info)
-        return;
-    
-    if (gw_applet->gweather_pref.use_metric) {
-        weather_info_to_metric (gw_applet->gweather_info);
-    }
-    else {    
-        weather_info_to_imperial (gw_applet->gweather_info); 
-    }
-    gtk_label_set_text(GTK_LABEL(gw_applet->label), 
-    		       weather_info_get_temp_summary(gw_applet->gweather_info));
-    gweather_dialog_update (gw_applet); 
-}
-
 static void
 detailed_toggled (GtkToggleButton *button, gpointer data)
 {
@@ -434,6 +386,239 @@ detailed_toggled (GtkToggleButton *button, gpointer data)
     				toggled, NULL);    
 }
 
+static void parse_temp_string (const gchar *gconf_str, GWeatherPrefs *prefs)
+{
+    gint value = 0;
+    char *imperial = NULL;
+	
+    prefs->use_temperature_default = TRUE;
+	
+    if ( gconf_str && gconf_string_to_enum (temp_unit_enum_map, gconf_str, &value) ) {
+        prefs->temperature_unit = value;
+		
+		if ((prefs->temperature_unit == TEMP_UNIT_DEFAULT) &&
+		    (gconf_string_to_enum (temp_unit_enum_map, _("DEFAULT_TEMP_UNIT"), &value)) ) {
+              prefs->temperature_unit = value;
+		} else {
+            prefs->use_temperature_default = FALSE;
+        }
+    }	
+    else {
+        /* TRANSLATOR: This is the default unit to use for temperature measurements. */
+        /* Valid values are: "K" (Kelvin), "C" (Centigrade) and "F" (Fahrenheit) */
+        if (gconf_string_to_enum (temp_unit_enum_map, _("DEFAULT_TEMP_UNIT"), &value) ) {
+            prefs->temperature_unit = value;
+        }
+    }
+    if (!prefs->temperature_unit || prefs->temperature_unit == TEMP_UNIT_DEFAULT ) {
+        imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
+        if ( imperial && imperial[0] == 2 )  {
+            /* imperial */
+            prefs->temperature_unit = TEMP_UNIT_FAHRENHEIT;
+        } else {
+            prefs->temperature_unit = TEMP_UNIT_CENTIGRADE;
+        }
+    }
+}
+
+static void parse_speed_string (const gchar *gconf_str, GWeatherPrefs *prefs)
+{
+    gint value = 0;
+    char *imperial = NULL;
+	
+    prefs->use_speed_default = TRUE;
+	
+    if ( gconf_str && gconf_string_to_enum (speed_unit_enum_map, gconf_str, &value) ) {
+        prefs->speed_unit = value;
+		if ((prefs->speed_unit == SPEED_UNIT_DEFAULT) &&
+			(gconf_string_to_enum (speed_unit_enum_map, _("DEFAULT_SPEED_UNIT"), &value)) ) {
+              prefs->speed_unit = value;
+		} else {
+            prefs->use_speed_default = FALSE;
+        }
+    }	
+    else {
+        /* TRANSLATOR: This is the default unit to use for wind speed. */
+        /* Valid values are: "m/s" (meters per second), "km/h" (kilometers per hour), */
+        /* "mph" (miles per hour) and "knots"  */
+        if (gconf_string_to_enum (speed_unit_enum_map, _("DEFAULT_SPEED_UNIT"), &value) ) {
+            prefs->speed_unit = value;
+        }
+    }
+    if ( (!prefs->speed_unit) || prefs->speed_unit == SPEED_UNIT_DEFAULT ) {
+        imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
+        if ( imperial && imperial[0] == 2 )  {
+            /* imperial */
+            prefs->speed_unit = SPEED_UNIT_KNOTS;
+        } else {
+            prefs->speed_unit = SPEED_UNIT_MS;
+        }
+    }
+}
+
+
+static void parse_pressure_string (const gchar *gconf_str, GWeatherPrefs *prefs)
+{
+    gint value = 0;
+    char *imperial = NULL;
+	
+    prefs->use_pressure_default = TRUE;
+	
+    if ( gconf_str && gconf_string_to_enum (pressure_unit_enum_map, gconf_str, &value) ) {
+        prefs->pressure_unit = value;
+
+        if ((prefs->pressure_unit == PRESSURE_UNIT_DEFAULT) &&
+			(gconf_string_to_enum (pressure_unit_enum_map, _("DEFAULT_PRESSURE_UNIT"), &value)) ) {
+              prefs->pressure_unit = value;
+		} else {
+            prefs->use_pressure_default = FALSE;
+        }
+    }	
+    else {
+        /* TRANSLATOR: This is the default unit to use for atmospheric pressure. */
+        /* Valid values are: "hPa" (hectoPascals), "mb" (millibars), "mmHg"  */
+		/* (millimeters of mercury) and "inHg" (inches of mercury) */
+        if (gconf_string_to_enum (pressure_unit_enum_map, _("DEFAULT_PRESSURE_UNIT"), &value) ) {
+            prefs->pressure_unit = value;
+        }
+    }
+    if ( (!prefs->pressure_unit) || prefs->pressure_unit == PRESSURE_UNIT_DEFAULT ) {
+        imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
+        if ( imperial && imperial[0] == 2 )  {
+            /* imperial */
+            prefs->pressure_unit = PRESSURE_UNIT_INCH_HG;
+        } else {
+            prefs->pressure_unit = PRESSURE_UNIT_HPA;
+        }
+    }	
+}
+
+static void parse_distance_string (const gchar *gconf_str, GWeatherPrefs *prefs)
+{
+    gint value = 0;
+    char *imperial = NULL;
+	
+    prefs->use_distance_default = TRUE;
+    if ( gconf_str && gconf_string_to_enum (distance_unit_enum_map, gconf_str, &value) ) {
+        prefs->distance_unit = value;
+
+		if ((prefs->distance_unit == DISTANCE_UNIT_DEFAULT) &&
+			(gconf_string_to_enum (distance_unit_enum_map, _("DEFAULT_DISTANCE_UNIT"), &value)) ) {
+              prefs->distance_unit = value;
+		} else {
+            prefs->use_distance_default = FALSE;
+        }
+    }	
+    else {
+        /* TRANSLATOR: This is the default unit to use for visibility distance. */
+        /* Valid values are: "m" (meters), "km" (kilometers) and "mi" (miles)   */
+        if (gconf_string_to_enum (distance_unit_enum_map, _("DEFAULT_DISTANCE_UNIT"), &value) ) {
+            prefs->distance_unit = value;
+        }
+    }
+
+	if ((!prefs->distance_unit) || prefs->distance_unit == DISTANCE_UNIT_DEFAULT ) {
+        imperial = nl_langinfo(_NL_MEASUREMENT_MEASUREMENT);
+        if ( imperial && imperial[0] == 2 )  {
+            /* imperial */
+            prefs->distance_unit = DISTANCE_UNIT_MILES;
+        } else {
+            prefs->distance_unit = DISTANCE_UNIT_METERS;
+        }
+    }
+
+    return;
+}	
+static void temp_combo_changed_cb (GtkComboBox *combo, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    TempUnit       new_unit, *old_unit;
+	
+	g_return_if_fail(gw_applet != NULL);
+    
+	old_unit = &gw_applet->gweather_pref.temperature_unit;	
+	new_unit = gtk_combo_box_get_active(combo) + 1;
+
+	if (new_unit == *old_unit)
+        return;
+
+    parse_temp_string (gconf_enum_to_string (temp_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
+
+    panel_applet_gconf_set_string(gw_applet->applet, GCONF_TEMP_UNIT,
+                                  gconf_enum_to_string (temp_unit_enum_map, new_unit),
+                                  NULL);
+	
+    gtk_label_set_text(GTK_LABEL(gw_applet->label), 
+	                   weather_info_get_temp_summary(gw_applet->gweather_info));
+    gweather_dialog_update (gw_applet);
+}
+
+static void speed_combo_changed_cb (GtkComboBox *combo, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    SpeedUnit      new_unit, *old_unit;
+	
+	g_return_if_fail(gw_applet != NULL);
+    
+	old_unit = &gw_applet->gweather_pref.speed_unit;	
+	new_unit = gtk_combo_box_get_active(combo) + 1;
+
+	if (new_unit == *old_unit)
+        return;
+
+    parse_speed_string (gconf_enum_to_string (speed_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
+
+    panel_applet_gconf_set_string(gw_applet->applet, GCONF_SPEED_UNIT,
+                                  gconf_enum_to_string (speed_unit_enum_map, new_unit),
+                                  NULL);
+	
+    gweather_dialog_update (gw_applet);
+}
+
+static void pres_combo_changed_cb (GtkComboBox *combo, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    PressureUnit   new_unit, *old_unit;
+	
+	g_return_if_fail(gw_applet != NULL);
+    
+	old_unit = &gw_applet->gweather_pref.pressure_unit;	
+	new_unit = gtk_combo_box_get_active(combo) + 1;
+
+	if (new_unit == *old_unit)
+        return;
+
+    parse_pressure_string (gconf_enum_to_string (pressure_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
+
+    panel_applet_gconf_set_string(gw_applet->applet, GCONF_PRESSURE_UNIT,
+                                  gconf_enum_to_string (pressure_unit_enum_map, new_unit),
+                                  NULL);
+	
+    gweather_dialog_update (gw_applet);
+}
+
+static void dist_combo_changed_cb (GtkComboBox *combo, gpointer data)
+{
+    GWeatherApplet *gw_applet = data;
+    DistanceUnit   new_unit, *old_unit;
+	
+	g_return_if_fail(gw_applet != NULL);
+    
+	old_unit = &gw_applet->gweather_pref.distance_unit;	
+	new_unit = gtk_combo_box_get_active(combo) + 1;
+
+	if (new_unit == *old_unit)
+        return;
+
+    parse_distance_string (gconf_enum_to_string (distance_unit_enum_map, new_unit), &(gw_applet->gweather_pref));
+
+    panel_applet_gconf_set_string(gw_applet->applet, GCONF_DISTANCE_UNIT,
+                                  gconf_enum_to_string (distance_unit_enum_map, new_unit),
+                                  NULL);
+	
+    gweather_dialog_update (gw_applet);
+}
+
 static void
 radar_toggled (GtkToggleButton *button, gpointer data)
 {
@@ -507,19 +692,12 @@ free_data (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer d
    GWeatherApplet *gw_applet = data;
    WeatherLocation *location;
    
-   gtk_tree_model_get (model, iter, COL_POINTER, &location, -1);
+   gtk_tree_model_get (model, iter, GWEATHER_PREF_COL_POINTER, &location, -1);
    if (!location)
    	return FALSE;
 
-   if (location->name)
-      	g_free (location->name);
-   if (location->code)
-      	g_free (location->code);
-   if (location->zone)
-      	g_free (location->zone);      	
-   if (location->radar)
-      	g_free (location->radar);	
    weather_location_free (location);
+   
    return FALSE;
 }
 
@@ -601,17 +779,26 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     GtkWidget *pref_basic_vbox;
     GtkWidget *vbox;
     GtkWidget *frame;
+    GtkWidget *temp_label;
+    GtkWidget *temp_combo;
+    GtkWidget *speed_label;
+    GtkWidget *speed_combo;	
+    GtkWidget *pres_label;
+    GtkWidget *pres_combo;
+    GtkWidget *dist_label;
+    GtkWidget *dist_combo;
+    GtkWidget *unit_table;	
     
     gw_applet->pref = gtk_dialog_new_with_buttons (_("Weather Preferences"), NULL,
 				      		   GTK_DIALOG_DESTROY_WITH_PARENT,
 				      		   GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
 				      		   GTK_STOCK_HELP, GTK_RESPONSE_HELP,
 				      		   NULL);
+
     gtk_dialog_set_default_response (GTK_DIALOG (gw_applet->pref), GTK_RESPONSE_CLOSE);
     gtk_dialog_set_has_separator (GTK_DIALOG (gw_applet->pref), FALSE);
     gtk_container_set_border_width (GTK_CONTAINER (gw_applet->pref), 5);
-    gtk_window_set_default_size(GTK_WINDOW (gw_applet->pref), -1, 325);
-    gtk_window_set_policy (GTK_WINDOW (gw_applet->pref), TRUE, TRUE, FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (gw_applet->pref), FALSE);
     gtk_window_set_screen (GTK_WINDOW (gw_applet->pref),
 			   gtk_widget_get_screen (GTK_WIDGET (gw_applet->applet)));
 
@@ -643,13 +830,113 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     if ( ! key_writable (gw_applet->applet, "auto_update"))
 	    hard_set_sensitive (gw_applet->pref_basic_update_btn, FALSE);
 
-    gw_applet->pref_basic_metric_btn = gtk_check_button_new_with_mnemonic (_("Use _metric system units"));
-    gtk_widget_show (gw_applet->pref_basic_metric_btn);
-    g_signal_connect (G_OBJECT (gw_applet->pref_basic_metric_btn), "toggled",
-    		      G_CALLBACK (metric_toggled), gw_applet);
-    if ( ! key_writable (gw_applet->applet, "enable_metric"))
-	    hard_set_sensitive (gw_applet->pref_basic_metric_btn, FALSE);
+    /* Temperature Unit */
+    temp_label = gtk_label_new_with_mnemonic (_("_Temperature Unit:"));
+    gtk_label_set_use_markup (GTK_LABEL (temp_label), TRUE);
+    gtk_label_set_justify (GTK_LABEL (temp_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (temp_label), 0, 0.5);
+    gtk_widget_show (temp_label);
 
+    temp_combo = gtk_combo_box_new_text ();
+	gw_applet->pref_basic_temp_combo = temp_combo;
+    gtk_label_set_mnemonic_widget (GTK_LABEL (temp_label), temp_combo);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Default"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Kelvin"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Centigrade"));
+    gtk_combo_box_append_text (GTK_COMBO_BOX (temp_combo), _("Fahrenheit"));
+	gtk_widget_show (temp_combo);
+		
+    if ( ! key_writable (gw_applet->applet, GCONF_TEMP_UNIT))
+        hard_set_sensitive (gw_applet->pref_basic_temp_combo, FALSE);
+	
+    /* Speed Unit */
+    speed_label = gtk_label_new_with_mnemonic (_("_Wind Speed Unit:"));
+    gtk_label_set_use_markup (GTK_LABEL (speed_label), TRUE);
+    gtk_label_set_justify (GTK_LABEL (speed_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (speed_label), 0, 0.5);
+    gtk_widget_show (speed_label);
+
+    speed_combo = gtk_combo_box_new_text ();
+    gw_applet->pref_basic_speed_combo = speed_combo;
+    gtk_label_set_mnemonic_widget (GTK_LABEL (speed_label), speed_combo);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (speed_combo), _("Default"));
+    /* TRANSLATOR: The wind speed unit "meters per second" */    
+    gtk_combo_box_append_text (GTK_COMBO_BOX (speed_combo), _("m/s"));
+    /* TRANSLATOR: The wind speed unit "kilometers per hour" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (speed_combo), _("km/h"));
+    /* TRANSLATOR: The wind speed unit "miles per hour" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (speed_combo), _("mph"));
+    /* TRANSLATOR: The wind speed unit "knots" */
+	gtk_combo_box_append_text (GTK_COMBO_BOX (speed_combo), _("knots"));
+	gtk_widget_show (speed_combo);
+
+    if ( ! key_writable (gw_applet->applet, GCONF_SPEED_UNIT))
+        hard_set_sensitive (gw_applet->pref_basic_speed_combo, FALSE);
+
+    /* Pressure Unit */
+    pres_label = gtk_label_new_with_mnemonic (_("_Pressure Unit:"));
+    gtk_label_set_use_markup (GTK_LABEL (pres_label), TRUE);
+    gtk_label_set_justify (GTK_LABEL (pres_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (pres_label), 0, 0.5);
+    gtk_widget_show (pres_label);
+
+    pres_combo = gtk_combo_box_new_text ();
+	gw_applet->pref_basic_pres_combo = pres_combo;
+    gtk_label_set_mnemonic_widget (GTK_LABEL (pres_label), pres_combo);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("Default"));
+    /* TRANSLATOR: The pressure unit "hectoPascals" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("hPa"));
+    /* TRANSLATOR: The pressure unit "millibars" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("mb"));
+    /* TRANSLATOR: The pressure unit "millibars of mercury" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("mmHg"));
+    /* TRANSLATOR: The pressure unit "inches of mercury" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (pres_combo), _("inHg"));
+    gtk_widget_show (pres_combo);
+
+    if ( ! key_writable (gw_applet->applet, GCONF_PRESSURE_UNIT))
+        hard_set_sensitive (gw_applet->pref_basic_pres_combo, FALSE);
+
+    /* Distance Unit */
+    dist_label = gtk_label_new_with_mnemonic (_("_Visibility Unit:"));
+    gtk_label_set_use_markup (GTK_LABEL (dist_label), TRUE);
+    gtk_label_set_justify (GTK_LABEL (dist_label), GTK_JUSTIFY_LEFT);
+    gtk_misc_set_alignment (GTK_MISC (dist_label), 0, 0.5);
+    gtk_widget_show (dist_label);
+
+    dist_combo = gtk_combo_box_new_text ();
+	gw_applet->pref_basic_dist_combo = dist_combo;
+    gtk_label_set_mnemonic_widget (GTK_LABEL (dist_label), dist_combo);
+    gtk_combo_box_append_text (GTK_COMBO_BOX (dist_combo), _("Default"));
+    /* TRANSLATOR: The distance unit "meters" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (dist_combo), _("meters"));
+    /* TRANSLATOR: The distance unit "kilometers" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (dist_combo), _("km"));
+    /* TRANSLATOR: The distance unit "miles" */
+    gtk_combo_box_append_text (GTK_COMBO_BOX (dist_combo), _("miles"));
+	gtk_widget_show (dist_combo);
+
+    if ( ! key_writable (gw_applet->applet, GCONF_DISTANCE_UNIT))
+        hard_set_sensitive (gw_applet->pref_basic_dist_combo, FALSE);
+	
+	unit_table = gtk_table_new(5, 3, FALSE);
+	gtk_table_set_row_spacings(GTK_TABLE(unit_table), 6);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), temp_label,  0, 1, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), temp_combo,  1, 2, 0, 1);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), speed_label, 0, 1, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), speed_combo, 1, 2, 1, 2);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), pres_label,  0, 1, 2, 3);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), pres_combo,  1, 2, 2, 3);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), dist_label,  0, 1, 3, 4);
+	gtk_table_attach_defaults(GTK_TABLE(unit_table), dist_combo,  1, 2, 3, 4);
+	gtk_widget_show(unit_table);
+	
+	g_signal_connect (temp_combo, "changed", G_CALLBACK (temp_combo_changed_cb), gw_applet);
+	g_signal_connect (speed_combo, "changed", G_CALLBACK (speed_combo_changed_cb), gw_applet);
+	g_signal_connect (dist_combo, "changed", G_CALLBACK (dist_combo_changed_cb), gw_applet);
+	g_signal_connect (pres_combo, "changed", G_CALLBACK (pres_combo_changed_cb), gw_applet);
+
+	
 #ifdef RADARMAP
     gw_applet->pref_basic_radar_btn = gtk_check_button_new_with_mnemonic (_("Enable _radar map"));
     gtk_widget_show (gw_applet->pref_basic_radar_btn);
@@ -665,7 +952,7 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_widget_show (label);
     gtk_box_pack_start (GTK_BOX (radar_toggle_hbox), label, FALSE, FALSE, 0); 
 					      
-    gw_applet->pref_basic_radar_url_btn = gtk_check_button_new_with_mnemonic (_("Use cus_tom address for radar map"));
+    gw_applet->pref_basic_radar_url_btn = gtk_check_button_new_with_mnemonic (_("Use _custom address for radar map"));
     gtk_widget_show (gw_applet->pref_basic_radar_url_btn);
     gtk_box_pack_start (GTK_BOX (radar_toggle_hbox), gw_applet->pref_basic_radar_url_btn, FALSE, FALSE, 0);
 
@@ -740,7 +1027,8 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
 
     vbox = gtk_vbox_new (FALSE, 6);
 
-    gtk_box_pack_start (GTK_BOX (vbox), gw_applet->pref_basic_metric_btn, TRUE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (vbox), unit_table, TRUE, TRUE, 0);
+
 #ifdef RADARMAP
     gtk_box_pack_start (GTK_BOX (vbox), gw_applet->pref_basic_radar_btn, TRUE, TRUE, 0);
     gtk_box_pack_start (GTK_BOX (vbox), radar_toggle_hbox, TRUE, TRUE, 0);
@@ -768,11 +1056,12 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     gtk_box_pack_start (GTK_BOX (pref_loc_hbox), tree_label, FALSE, FALSE, 0);
 
     scrolled_window = gtk_scrolled_window_new (NULL, NULL);
+    gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (scrolled_window), GTK_SHADOW_IN);
     gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (scrolled_window),
 				    GTK_POLICY_AUTOMATIC,
 				    GTK_POLICY_AUTOMATIC);
 
-    model = gtk_tree_store_new (NUM_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
+    model = gtk_tree_store_new (GWEATHER_PREF_NUM_COLUMNS, G_TYPE_STRING, G_TYPE_POINTER);
     gw_applet->pref_tree = gtk_tree_view_new_with_model (GTK_TREE_MODEL (model));
     gtk_label_set_mnemonic_widget (GTK_LABEL (tree_label), GTK_WIDGET (gw_applet->pref_tree));
     gtk_tree_view_set_headers_visible (GTK_TREE_VIEW (gw_applet->pref_tree), FALSE);
@@ -801,20 +1090,25 @@ static void gweather_pref_create (GWeatherApplet *gw_applet)
     		      G_CALLBACK (response_cb), gw_applet);
    
     gweather_pref_set_accessibility (gw_applet); 
-    add_atk_relation (gw_applet->pref_basic_update_spin, pref_basic_update_sec_lbl,
-                                            ATK_RELATION_LABELLED_BY);
-    add_atk_relation (gw_applet->pref_basic_radar_url_entry, label, ATK_RELATION_LABELLED_BY);
- 
-
+    gtk_label_set_mnemonic_widget (GTK_LABEL (pref_basic_update_sec_lbl), gw_applet->pref_basic_update_spin);
+    gtk_label_set_mnemonic_widget (GTK_LABEL (label), gw_applet->pref_basic_radar_url_entry);
 
     gtk_widget_show_all (gw_applet->pref);
 }
 
-
 void gweather_pref_load (GWeatherApplet *gw_applet)
 {
     GError *error = NULL;
+	gchar  *gconf_str = NULL;
+	gint   value = 0;
+	GWeatherPrefs *prefs = &(gw_applet->gweather_pref);
 
+	/* Assume we use unit defaults */
+	prefs->use_temperature_default = TRUE;
+    prefs->use_speed_default = TRUE;
+    prefs->use_pressure_default = TRUE;
+    prefs->use_distance_default = TRUE;
+	
     gw_applet->gweather_pref.update_interval = 
     	panel_applet_gconf_get_int(gw_applet->applet, "auto_update_interval", &error);
     if (error) {
@@ -825,8 +1119,6 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
     gw_applet->gweather_pref.update_interval = MAX (gw_applet->gweather_pref.update_interval, 60);
     gw_applet->gweather_pref.update_enabled =
     	panel_applet_gconf_get_bool(gw_applet->applet, "auto_update", NULL);
-    gw_applet->gweather_pref.use_metric = 
-    	panel_applet_gconf_get_bool(gw_applet->applet, "enable_metric", NULL);
     gw_applet->gweather_pref.detailed =
     	panel_applet_gconf_get_bool(gw_applet->applet, "enable_detailed_forecast", NULL);
     gw_applet->gweather_pref.radar_enabled =
@@ -837,6 +1129,24 @@ void gweather_pref_load (GWeatherApplet *gw_applet)
     gw_applet->gweather_pref.radar = panel_applet_gconf_get_string (gw_applet->applet,
     								    "radar",
     								    NULL);
+    
+    gconf_str = panel_applet_gconf_get_string (gw_applet->applet, GCONF_TEMP_UNIT, NULL);
+    parse_temp_string(gconf_str, prefs);
+	g_free (gconf_str);
+    
+		
+    gconf_str = panel_applet_gconf_get_string (gw_applet->applet, GCONF_SPEED_UNIT, NULL);
+	parse_speed_string(gconf_str, prefs);
+	g_free (gconf_str);
+			
+    gconf_str = panel_applet_gconf_get_string (gw_applet->applet, GCONF_PRESSURE_UNIT, NULL);
+	parse_pressure_string(gconf_str, prefs);
+	g_free (gconf_str);
+
+    gconf_str = panel_applet_gconf_get_string (gw_applet->applet, GCONF_DISTANCE_UNIT, NULL);
+	parse_distance_string(gconf_str, prefs);
+	g_free (gconf_str);
+	
     return;
 }
 
@@ -869,4 +1179,3 @@ void gweather_pref_run (GWeatherApplet *gw_applet)
 
     
 }
-
