@@ -134,6 +134,9 @@ struct _MailCheck {
 	/* for the selection routine */
 	char *selected_pixmap_name;
 
+	/* the about box */
+	GtkWidget *about;
+
 	/* The property window */
 	GtkWidget *property_window;
 	GtkWidget *min_spin, *sec_spin;
@@ -141,9 +144,6 @@ struct _MailCheck {
 	GtkWidget *newmail_cmd_entry, *newmail_cmd_check;
 	GtkWidget *clicked_cmd_entry, *clicked_cmd_check;
 
-	/* the about box */
-	GtkWidget *about;
-
 	GtkWidget *password_dialog;
 
 	gboolean anim_changed;
@@ -643,6 +643,7 @@ set_tooltip (GtkWidget  *applet,
 	}
 
 	gtk_tooltips_set_tip (tooltips, applet, tip, NULL);
+	set_atk_name_description (applet, tip, "");
 }
 
 static void
@@ -651,8 +652,9 @@ mailcheck_execute_shell (MailCheck  *mailcheck,
 {
 	GError *error = NULL;
 
-	egg_screen_execute_command_line_async (
-		gtk_widget_get_screen (GTK_WIDGET (mailcheck->applet)), command, &error);
+	gdk_spawn_command_line_on_screen (gtk_widget_get_screen (GTK_WIDGET (mailcheck->applet)),
+					  command, &error); 
+
 	if (error) {
 		GtkWidget *dialog;
 		char *msg;
@@ -1224,7 +1226,7 @@ exec_clicked_cmd (GtkWidget *widget, GdkEventButton *event, gpointer data)
 	MailCheck *mc = data;
 	gboolean retval = FALSE;
 
-	if (event->button == 1 && event->type == GDK_2BUTTON_PRESS) {
+	if (event->button == 1 && event->type == GDK_BUTTON_PRESS) {
 
 		if (mc->clicked_enabled && mc->clicked_cmd && (strlen(mc->clicked_cmd) > 0))
 			mailcheck_execute_shell (mc, mc->clicked_cmd);
@@ -1422,7 +1424,15 @@ make_remote_widgets_sensitive(MailCheck *mc)
 	gboolean b = mc->mailbox_type != MAILBOX_LOCAL &&
 	             mc->mailbox_type != MAILBOX_LOCALDIR;
         gboolean f = mc->mailbox_type == MAILBOX_IMAP;
+	gboolean p = mc->mailbox_type == MAILBOX_POP3;
 	
+	soft_set_sensitive (mc->newmail_cmd_check, !p);
+	if (p)
+		soft_set_sensitive (mc->newmail_cmd_entry, !p);
+	else
+		soft_set_sensitive (mc->newmail_cmd_entry, mc->newmail_enabled);
+	soft_set_sensitive (mc->play_sound_check, !p);
+
 	soft_set_sensitive (mc->mailfile_fentry, !b);
 	soft_set_sensitive (mc->mailfile_label, !b);
 	
@@ -1447,7 +1457,7 @@ mail_file_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->mail_file);
+	if (mc->mail_file)
 		g_free (mc->mail_file);
 		
 	mc->mail_file = text;
@@ -1464,7 +1474,7 @@ remote_server_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->remote_server);
+	if (mc->remote_server)
 		g_free (mc->remote_server);
 		
 	mc->remote_server = text;
@@ -1482,7 +1492,7 @@ remote_username_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->remote_username);
+	if (mc->remote_username)
 		g_free (mc->remote_username);
 		
 	mc->remote_username = text;
@@ -1537,7 +1547,7 @@ remote_folder_changed (GtkEntry *entry, gpointer data)
 	if (!text)
 		return;
 		
-	if (mc->remote_folder);
+	if (mc->remote_folder)
 		g_free (mc->remote_folder);
 		
 	mc->remote_folder = text;
@@ -2141,7 +2151,7 @@ mailcheck_properties_page (MailCheck *mc)
 		hard_set_sensitive (mc->play_sound_check, FALSE);
 
 	/*l = gtk_check_button_new_with_mnemonic (_("Set the number of unread mails to _zero when clicked"));*/
-	l = gtk_check_button_new_with_mnemonic (_("Sto_p animation when double clicked"));
+	l = gtk_check_button_new_with_mnemonic (_("Sto_p animation when clicked"));
 	gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->reset_on_clicked);
 	g_signal_connect(G_OBJECT(l), "toggled",
 			   G_CALLBACK(reset_on_clicked_toggled), mc);
@@ -2257,7 +2267,7 @@ mailcheck_properties_page (MailCheck *mc)
 		if ( ! key_writable (mc->applet, "newmail_command"))
 			hard_set_sensitive (mc->newmail_cmd_entry, FALSE);
 
-		l = gtk_check_button_new_with_mnemonic (_("When double clicke_d:"));
+		l = gtk_check_button_new_with_mnemonic (_("When clicke_d:"));
 		gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(l), mc->clicked_enabled);
 		g_signal_connect(G_OBJECT(l), "toggled",
 				 G_CALLBACK(clicked_toggled), mc);
@@ -2462,6 +2472,7 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 	if (mc->about) {
 		gtk_window_set_screen (GTK_WINDOW (mc->about),
 				       gtk_widget_get_screen (GTK_WIDGET (mc->applet)));
+
 		gtk_window_present (GTK_WINDOW (mc->about));
 		return;
 	}
@@ -2479,6 +2490,7 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 				     pixbuf);
 				     
 	gtk_window_set_wmclass (GTK_WINDOW (mc->about), "mailcheck", "Mailcheck");
+
 	gtk_window_set_screen (GTK_WINDOW (mc->about),
 			       gtk_widget_get_screen (GTK_WIDGET (mc->applet)));
 
@@ -2487,6 +2499,7 @@ mailcheck_about(BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 
 	g_signal_connect( G_OBJECT(mc->about), "destroy",
 			    G_CALLBACK(gtk_widget_destroyed), &mc->about );
+
 	gtk_widget_show(mc->about);
 }
 
@@ -2540,6 +2553,39 @@ applet_change_orient(PanelApplet * w, PanelAppletOrient orient, gpointer data)
 
 }
 
+static void
+applet_change_background(PanelApplet *a,
+			 PanelAppletBackgroundType type,
+			 GdkColor *color, GdkPixmap *pixmap,
+			 MailCheck *mc)
+{
+	GtkRcStyle *rc_style = gtk_rc_style_new ();
+
+	switch (type) {
+		case PANEL_PIXMAP_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (mc->ebox), rc_style);
+			gtk_widget_modify_style (GTK_WIDGET (mc->applet), rc_style);
+			break;
+
+		case PANEL_COLOR_BACKGROUND:
+			gtk_widget_modify_bg (GTK_WIDGET (mc->ebox), GTK_STATE_NORMAL, color);
+			gtk_widget_modify_bg (GTK_WIDGET (mc->applet), GTK_STATE_NORMAL, color);
+			break;
+
+		case PANEL_NO_BACKGROUND:
+			gtk_widget_modify_style (GTK_WIDGET (mc->ebox), rc_style);
+			gtk_widget_modify_style (GTK_WIDGET (mc->applet), rc_style);
+			break;
+
+		default:
+			gtk_widget_modify_style (GTK_WIDGET (mc->ebox), rc_style);
+			gtk_widget_modify_style (GTK_WIDGET (mc->applet), rc_style);
+			break;
+	}
+
+	gtk_rc_style_unref (rc_style);
+}
+
 static void
 help_callback (BonoboUIComponent *uic, MailCheck *mc, const gchar *verbname)
 {
@@ -2683,6 +2729,7 @@ create_mail_widgets (MailCheck *mc)
 
 	/* The label */
 	mc->label = gtk_label_new (NULL);
+	gtk_label_set_justify (GTK_LABEL (mc->label), GTK_JUSTIFY_CENTER);
 	gtk_label_set_line_wrap (GTK_LABEL (mc->label), TRUE);
 	gtk_widget_show (mc->label);
 	gtk_widget_ref (mc->label);
@@ -2738,8 +2785,10 @@ set_atk_relation (GtkWidget *widget1, GtkWidget *widget2, AtkRelationType relati
 	atk_widget2 = gtk_widget_get_accessible (widget2);
 
 	/* Set the label-for relation only if label-by is being set */
-	if (relation_type == ATK_RELATION_LABELLED_BY) 
+	if (relation_type == ATK_RELATION_LABELLED_BY) {
 		gtk_label_set_mnemonic_widget (GTK_LABEL (widget2), widget1); 
+		return;
+	}
 
 	/* Check if gail is loaded */
 	if (GTK_IS_ACCESSIBLE (atk_widget1) == FALSE)
@@ -2810,15 +2859,22 @@ mailcheck_applet_fill (PanelApplet *applet)
 			 G_CALLBACK(applet_change_orient),
 			 mc);
 
+	g_signal_connect(G_OBJECT(applet), "change_background",
+			 G_CALLBACK(applet_change_background),
+			 mc);
+
 	mailcheck = create_mail_widgets (mc);
 	gtk_widget_show(mailcheck);
 
 	gtk_container_add (GTK_CONTAINER (applet), mailcheck);
 
 	g_signal_connect(G_OBJECT(mc->ebox), "button_press_event",
-			 G_CALLBACK(exec_clicked_cmd), mc);
+			 G_CALLBACK(exec_clicked_cmd),
+			 mc);
+
 	g_signal_connect(G_OBJECT(applet), "key_press_event",
-			 G_CALLBACK(key_press_cb), mc);
+			 G_CALLBACK(key_press_cb),
+			 mc);
 
 	panel_applet_setup_menu_from_file (applet,
 					   NULL,
