@@ -93,10 +93,13 @@ load_graph_update (LoadGraph *g)
 {
     guint i, j;
 
-	if (g->tooltip_update)
-		multiload_applet_tooltip_update(g);
-	else		
-	    g->get_data (g->draw_height, g->data [0], g);
+    if (g->data == NULL)
+	return TRUE;
+    
+    if (g->tooltip_update)
+	multiload_applet_tooltip_update(g);
+    else		
+	g->get_data (g->draw_height, g->data [0], g);
 
     for (i=0; i < g->draw_width-1; i++)
 		for (j=0; j < g->n; j++)
@@ -110,7 +113,6 @@ void
 load_graph_unalloc (LoadGraph *g)
 {
     int i;
-	gchar name[32];
 	
     if (!g->allocated)
 		return;
@@ -128,7 +130,6 @@ load_graph_unalloc (LoadGraph *g)
     g->pos = NULL;
     g->data = g->odata = NULL;
     
-    g_snprintf(name, sizeof(name), "%s_size", g->name);
     g->size = panel_applet_gconf_get_int(g->applet, "size", NULL);
     g->size = MAX (g->size, 10);
 
@@ -221,7 +222,6 @@ load_graph_destroy (GtkWidget *widget, gpointer data_ptr)
     LoadGraph *g = (LoadGraph *) data_ptr;
 	
     load_graph_stop (g);
-
     gtk_widget_destroy(widget);
     object_list = g_list_remove (object_list, g);
     return;
